import {useState} from "react";
import {Button, Grid, TextField} from "@mui/material";

const ProductForm = ({createProductHandler}) => {
    const [state, setState] = useState({
        title: "",
        price: "",
        description: ""
    });

    const submitFormHandler = e => {
        e.preventDefault();
        createProductHandler(state);
    };

    const inputChangeHandler = e => {
        const name = e.target.name;
        const value = e.target.value;

        setState(prevState => {
            return {...prevState, [name]: value};
        });
    };

    return (
        <form
            autoComplete="off"
            onSubmit={submitFormHandler}
        >
            <Grid container direction="column" spacing={2}>
                <Grid item xs>
                    <TextField
                        fullWidth
                        variant="outlined"
                        id="title"
                        label="Title"
                        value={state.title}
                        onChange={inputChangeHandler}
                        name="title"
                    />
                </Grid>
                <Grid item xs>
                    <TextField
                        fullWidth
                        variant="outlined"
                        id="price"
                        label="Price"
                        value={state.price}
                        onChange={inputChangeHandler}
                        name="price"
                    />
                </Grid>
                <Grid item xs>
                    <TextField
                        fullWidth
                        multiline
                        rows={3}
                        variant="outlined"
                        id="description"
                        label="Description"
                        value={state.description}
                        onChange={inputChangeHandler}
                        name="description"
                    />
                </Grid>
                <Grid item xs>
                    <Button type="submit" color="primary" variant="contained">Create</Button>
                </Grid>
            </Grid>
        </form>
    );
};

export default ProductForm;
